gcc9 snapshot 20190414 is 30x slower than gcc 6.3
Jason Mancini
jayrusman@hotmail.com
Mon Apr 29 20:33:00 GMT 2019
Jason Mancini said:
> We've determined that the gcc perf drop is due to use of decltype(auto) as the
> return type for template functions. Replacing with a known type or func(...) -> decltype(...)
> trailing type syntax seems to avoid the performance issue.
I misspoke here. Turns out that the above replacement made everything equally slow.
So the performance bug was lurking in there, and gcc-7-branch r249333 exposed it more.
Yeah yeah, we need to get an offending code blob cleaned up, approved, and bug filed.
I've been using gcc9 snapshots with part of r249333 reverted in the mean time to make
forward progress vetting gcc9 on our code base (no other problems so far!)
Jason
More information about the Gcc-help
mailing list